==> v21.04.tar.gz: bookstack/resources/lang/ar/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'إلغاء',
    'confirm' => 'تأكيد',
    'back' => 'رجوع',
    'save' => 'حفظ',
    'continue' => 'استمرار',
    'select' => 'تحديد',
    'toggle_all' => 'تبديل الكل',
    'more' => 'المزيد',

    // Form Labels
    'name' => 'الاسم',
    'description' => 'الوصف',
    'role' => 'الدور',
    'cover_image' => 'صورة الغلاف',
    'cover_image_description' => 'الصورة يجب أن تكون مقاربة لحجم 440×250 بكسل.',
    
    // Actions
    'actions' => 'إجراءات',
    'view' => 'عرض',
    'view_all' => 'عرض الكل',
    'create' => 'إنشاء',
    'update' => 'تحديث',
    'edit' => 'تعديل',
    'sort' => 'سرد',
    'move' => 'نقل',
    'copy' => 'نسخ',
    'reply' => 'رد',
    'delete' => 'حذف',
    'delete_confirm' => 'تأكيد الحذف',
    'search' => 'بحث',
    'search_clear' => 'مسح البحث',
    'reset' => 'إعادة تعيين',
    'remove' => 'إزالة',
    'add' => 'إضافة',
    'fullscreen' => 'شاشة كاملة',

    // Sort Options
    'sort_options' => 'خيارات الترتيب',
    'sort_direction_toggle' => 'الترتيب وفق الإتجاه',
    'sort_ascending' => 'فرز تصاعدي',
    'sort_descending' => 'فرز تنازلي',
    'sort_name' => 'الاسم',
    'sort_default' => 'Default',
    'sort_created_at' => 'تاريخ الإنشاء',
    'sort_updated_at' => 'تاريخ التحديث',

    // Misc
    'deleted_user' => 'حذف مستخدم',
    'no_activity' => 'لا يوجد نشاط لعرضه',
    'no_items' => 'لا توجد عناصر متوفرة',
    'back_to_top' => 'العودة للبداية',
    'toggle_details' => 'عرض / إخفاء التفاصيل',
    'toggle_thumbnails' => 'عرض / إخفاء الصور المصغرة',
    'details' => 'التفاصيل',
    'grid_view' => 'عرض شبكي',
    'list_view' => 'عرض منسدل',
    'default' => 'افتراضي',
    'breadcrumb' => 'شريط التنقل',

    // Header
    'profile_menu' => 'قائمة ملف التعريف',
    'view_profile' => 'عرض الملف الشخصي',
    'edit_profile' => 'تعديل الملف الشخصي',
    'dark_mode' => 'الوضع المظلم',
    'light_mode' => 'الوضع المضيء',

    // Layout tabs
    'tab_info' => 'معلومات',
    'tab_content' => 'المحتوى',

    // Email Content
    'email_action_help' => 'إذا واجهتكم مشكلة بضغط زر ":actionText" فبإمكانكم نسخ الرابط أدناه ولصقه بالمتصفح:',
    'email_rights' => 'جميع الحقوق محفوظة',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Privacy Policy',
    'terms_of_service' => 'Terms of Service',
];

==> v21.05.tar.gz: bookstack/resources/lang/ar/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'إلغاء',
    'confirm' => 'تأكيد',
    'back' => 'رجوع',
    'save' => 'حفظ',
    'continue' => 'استمرار',
    'select' => 'تحديد',
    'toggle_all' => 'تبديل الكل',
    'more' => 'المزيد',

    // Form Labels
    'name' => 'الاسم',
    'description' => 'الوصف',
    'role' => 'الدور',
    'cover_image' => 'صورة الغلاف',
    'cover_image_description' => 'الصورة يجب أن تكون مقاربة لحجم 440×250 بكسل.',
    
    // Actions
    'actions' => 'إجراءات',
    'view' => 'عرض',
    'view_all' => 'عرض الكل',
    'create' => 'إنشاء',
    'update' => 'تحديث',
    'edit' => 'تعديل',
    'sort' => 'سرد',
    'move' => 'نقل',
    'copy' => 'نسخ',
    'reply' => 'رد',
    'delete' => 'حذف',
    'delete_confirm' => 'تأكيد الحذف',
    'search' => 'بحث',
    'search_clear' => 'مسح البحث',
    'reset' => 'إعادة تعيين',
    'remove' => 'إزالة',
    'add' => 'إضافة',
    'fullscreen' => 'شاشة كاملة',
    'favourite' => 'Favourite',
    'unfavourite' => 'Unfavourite',
    'next' => 'Next',
    'previous' => 'Previous',

    // Sort Options
    'sort_options' => 'خيارات الفرز',
    'sort_direction_toggle' => 'الفرز وفق الاتجاه',
    'sort_ascending' => 'فرز تصاعدي',
    'sort_descending' => 'فرز تنازلي',
    'sort_name' => 'الاسم',
    'sort_default' => 'افتراضي',
    'sort_created_at' => 'تاريخ الإنشاء',
    'sort_updated_at' => 'تاريخ التحديث',

    // Misc
    'deleted_user' => 'المستخدم المحذوف',
    'no_activity' => 'لا يوجد نشاط لعرضه',
    'no_items' => 'لا توجد عناصر متوفرة',
    'back_to_top' => 'العودة إلى الأعلى',
    'toggle_details' => 'عرض / إخفاء التفاصيل',
    'toggle_thumbnails' => 'عرض / إخفاء الصور المصغرة',
    'details' => 'التفاصيل',
    'grid_view' => 'عرض شبكي',
    'list_view' => 'عرض منسدل',
    'default' => 'افتراضي',
    'breadcrumb' => 'شريط التنقل',

    // Header
    'header_menu_expand' => 'عرض القائمة',
    'profile_menu' => 'قائمة ملف التعريف',
    'view_profile' => 'عرض الملف الشخصي',
    'edit_profile' => 'تعديل الملف الشخصي',
    'dark_mode' => 'الوضع المظلم',
    'light_mode' => 'الوضع المضيء',

    // Layout tabs
    'tab_info' => 'معلومات',
    'tab_info_label' => 'تبويب: إظهار المعلومات الثانوية',
    'tab_content' => 'المحتوى',
    'tab_content_label' => 'تبويب: إظهار المحتوى الأساسي',

    // Email Content
    'email_action_help' => 'إذا واجهتكم مشكلة عند ضغط زر ":actionText" فبإمكانكم نسخ الرابط أدناه ولصقه بالمتصفح:',
    'email_rights' => 'جميع الحقوق محفوظة',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'سياسة الخصوصية',
    'terms_of_service' => 'اتفاقية شروط الخدمة',
];
